@@ -1,13 +1,13 @@
+import pathlib
 import shutil
 
 import requests
 
 from wi1_bot.config import config
 
-shutil.copy(
-    "./tests/files/jellyfish-10-mbps-hd-h264.mkv.bak",
-    "./tests/files/jellyfish-10-mbps-hd-h264.mkv",
-)
+path = pathlib.Path("./tests/files/jellyfish-10-mbps-hd-h264.mkv")
+
+shutil.copy(f"{path}.bak", path)
 
 header = {
     "X-Api-Key": config["radarr"]["api_key"],
@@ -19,7 +19,7 @@ data = {
         "id": 1,  # just to get quality profile
         "folderPath": "./tests/files",
     },
-    "movieFile": {"relativePath": "jellyfish-10-mbps-hd-h264.mkv"},
+    "movieFile": {"relativePath": path.name},
 }
 
 requests.post("http://localhost:9000/", json=data)
