@@ -26,6 +26,7 @@ if _config_path is None:
 class ArrConfig(TypedDict):
     url: str
     api_key: str
+    root_folder: str
 
 
 class PushoverConfig(TypedDict):
@@ -79,6 +80,7 @@ class DiscordConfig(DiscordConfigOptional):
 
 
 class TranscodingProfile(TypedDict, total=False):
+    copy_all_streams: bool
     video_codec: str
     video_bitrate: int
     audio_codec: str
