@@ -32,10 +32,12 @@ async def on_command_error(ctx: commands.Context, error: commands.CommandError)
             await reply(ctx.message, "you don't have permission to do that")
         case commands.MemberNotFound():
             await reply(ctx.message, "that user doesn't exist")
+        case commands.CommandOnCooldown():
+            await reply(ctx.message, str(error))
         case commands.MissingRequiredArgument():
             await reply(ctx.message, str(error))
         case _:
-            logger.error(repr(error))
+            logger.error(error, exc_info=True)
             await reply(
                 ctx.message,
                 f"something went wrong (<@!{config['discord']['admin_id']}>)",
